@@ -1,6 +1,6 @@
 .rebmix <- structure(list(
 Preprocessing = c("histogram", "Parzen window", "k-nearest neighbour"),
-Criterion = c("AIC", "AIC3", "AIC4", "AICc", "BIC", "CAIC", "HQC", "MDL2", "MDL5", "AWE", "CLC", "ICL", "ICL-BIC", "D", "SSE"),
+Criterion = c("AIC", "AIC3", "AIC4", "AICc", "BIC", "CAIC", "HQC", "MDL2", "MDL5", "AWE", "CLC", "ICL", "ICL-BIC", "PC", "D", "SSE"),
 Variables = c("continuous", "discrete"),
 pdf = c("normal", "lognormal", "Weibull", "binomial", "Poisson", "Dirac", "gamma"),
 pdf.nargs = c(2, 2, 2, 2, 1, 1, 2),
